import pprint
import json
import pyperler
import pathlib

__author__ = "Manuel Rueda"
__copyright__ = "Copyright 2022-2023, Manuel Rueda - CNAG"
__credits__ = ["None"]
__license__ = "Artistic License 2.0"
__version__ = "0.14"
__maintainer__ = "Manuel Rueda"
__email__ = "manuel.rueda@cnag.eu"
__status__ = "Production"


class PythonBinding:

    def __init__(self, json):
        self.json = json

    def convert_pheno(self):

        # Create interpreter
        i = pyperler.Interpreter()

        ##############################
        # Only if the module WAS NOT #
        # installed from CPAN        #
        ##############################
        # We have to provide the path to <convert-pheno/lib>
        bindir = pathlib.Path(__file__).resolve().parent
        lib_str = "lib '" + str(bindir) + "'"
        lib_str_conda = "lib '" + str(bindir) + '/lib/perl5/site_perl/' + "'" # conda
        i.use(lib_str)
        i.use(lib_str_conda)

        # Load the module
        CP = i.use('Convert::Pheno')

        # Create object
        convert = CP.new(self.json)

        # The result of the method (e.g. 'pxf2bff()') comes out
        #  as a scalar (Perl hashref)
        # type(hashref) = pyperler.ScalarValue
        hashref = getattr(convert, self.json["method"])()

        # The data structure is accesible via pprint
        # pprint.pprint(hashref)
        # Casting works within print...
        # print(dict(hashref))
        # ... but fails with json.dumps
        # print(json.dumps(dict(hashref)))

        # Trick to serialize it back to a correct Python dictionary
        json_dict = json.loads((pprint.pformat(hashref)).replace("'", '"'))

        # Return dict
        return json_dict



#!/usr/bin/env python3
#
#   Example script on how to use Convert::Pheno in Python
#
#   This file is part of Convert::Pheno
#
#   Last Modified: Dec/14/2022
#
#   $VERSION taken from Convert::Pheno
#
#   Copyright (C) 2022-2024 Manuel Rueda - CNAG (manuel.rueda@cnag.eu)
#
#   License: Artistic License 2.0

import json
import sys
sys.path.append('../../lib/')
sys.path.append('lib/perl5/site_perl/')
from convertpheno import PythonBinding


def main():

    # Example PXF data
    my_pxf_json_data = {
      "phenopacket": {
        "id": "P0007500",
        "subject": {
          "id": "P0007500",
          "dateOfBirth": "unknown-01-01T00:00:00Z",
          "sex": "FEMALE"
        }
      }
    }

    # Create dictionary
    json_data = {
        "method": "pxf2bff",
        "data": my_pxf_json_data
    }

    # Creating object for class PythonBinding
    convert = PythonBinding(json_data)

    # Run method convert_pheno and beautify with json.dumps
    print(json.dumps(convert.convert_pheno(), indent=4, sort_keys=True))


if __name__ == "__main__":
    main()
